Subject: bug#36639: closed (Re: bug#36639: Add Georgian QWERTY input methods)

From: [email-masked] (GNU bug Tracking System)
Date: Sun, 14 Jul 2019 06:58:02 +0000

Your bug report

#36639: Add Georgian QWERTY input methods

which was filed against the emacs package, has been closed.

The explanation is attached below, along with your original report.
If you require more details, please reply to [email-masked].

-- 
36639: http://debbugs.gnu.org/cgi/bugreport.cgi?bug=36639
GNU Bug Tracking System
Contact [email-masked] with problems

Subject: Re: bug#36639: Add Georgian QWERTY input methods
From: Eli Zaretskii <[email-masked]>
To: Nicholas Drozd <[email-masked]>
Cc: [email-masked]
Date: Sun, 14 Jul 2019 09:56:50 +0300
List-Id: <debbugs-submit.debbugs.gnu.org>

> From: Nicholas Drozd <[email-masked]>
> Date: Sat, 13 Jul 2019 13:03:21 -0500
> 
> I wasn't sure how to format the commit messages, so feel free to
> adjust those as needed, or combine commits or whatever.

The rules for formatting log messages are in CONTRIBUTE.

Thanks, I pushed this to the master branch.

Subject: Add Georgian QWERTY input methods
From: Nicholas Drozd <[email-masked]>
To: [email-masked]
Date: Sat, 13 Jul 2019 13:03:21 -0500
List-Id: <debbugs-submit.debbugs.gnu.org>

The existing Georgian input method is based on a transliteration
scheme, but that scheme doesn't match what is normally used on
Georgian keyboards. This patch adds an input method 'georgian-qwerty'
that allows for typing Georgian according to the more familiar layout
based on QWERTY keyboards. (That layout doesn't really make sense from
a linguistic perspective, but again, it is the familiar one.) Also
included is an input method 'georgian-nuskhuri'. It's just like
'georgian-qwerty' except that it uses the Nuskhuri script, which will
make it more convenient to transcribe medieval Georgian manuscripts.
This will obviously be a huge time-saver for many Emacs users.

Apart from these new input methods, there are also patches to correct
some minor mistakes. One is to add two missing characters to the
existing 'georgian' input method. Maybe the Unicode characters didn't
exist when the input method was created? The other is to change
ქართველი (Kartveli) to ქართული (Kartuli) in the HELLO file. The latter
is the appropriate adjective for the Georgian language (ქართული ენა).

I wasn't sure how to format the commit messages, so feel free to
adjust those as needed, or combine commits or whatever.

Are there any Georgians here who can test this out?
From 8b35204f70c411ce7e8c26e24e22cb8a0e8ad1cc Mon Sep 17 00:00:00 2001
From: Nick Drozd <[email-masked]>
Date: Sat, 13 Jul 2019 12:03:36 -0500
Subject: [PATCH 1/5] * lisp/leim/quail/georgian.el: Add georgian-qwerty input
 method

---
 lisp/leim/quail/georgian.el | 57 +++++++++++++++++++++++++++++++++++--
 1 file changed, 55 insertions(+), 2 deletions(-)

-- 
2.17.1

From 151119f31724a7b4b1f81a7156cb54bf4e2ae6a0 Mon Sep 17 00:00:00 2001
From: Nick Drozd <[email-masked]>
Date: Sat, 13 Jul 2019 12:03:54 -0500
Subject: [PATCH 2/5] * lisp/leim/quail/georgian.el: Add missing characters to
 georgian input

---
 lisp/leim/quail/georgian.el | 6 ++----
 1 file changed, 2 insertions(+), 4 deletions(-)

diff --git a/lisp/leim/quail/georgian.el b/lisp/leim/quail/georgian.el
index 7ca3f79a81..52f035f95d 100644
--- a/lisp/leim/quail/georgian.el
+++ b/lisp/leim/quail/georgian.el
@@ -78,10 +78,8 @@
  ("i1" ?ჲ)
  ("w" ?ჳ)
  ("f" ?ჶ)
- ;; Presumably, these are GEORGIAN LETTER YN, GEORGIAN LETTER ELIFI,
- ;; accepted for U+10F7, U+10F8  -- fx
- ("y" ?) ;; Letter not in Unicode (private use code).
- ("e1" ?) ;; Letter not in Unicode (private use code).
+ ("y" ?ჷ)
+ ("e1" ?ჸ)
  )
 
 (quail-define-package
-- 
2.17.1

From aa0ece071d3d5eb6e1bee9326872707f35a627ca Mon Sep 17 00:00:00 2001
From: Nick Drozd <[email-masked]>
Date: Sat, 13 Jul 2019 12:04:05 -0500
Subject: [PATCH 3/5] * lisp/leim/quail/georgian.el: Add georgian-nuskhuri
 input method

---
 lisp/leim/quail/georgian.el | 48 +++++++++++++++++++++++++++++++++++++
 1 file changed, 48 insertions(+)

diff --git a/lisp/leim/quail/georgian.el b/lisp/leim/quail/georgian.el
index 52f035f95d..a1cdb58465 100644
--- a/lisp/leim/quail/georgian.el
+++ b/lisp/leim/quail/georgian.el
@@ -28,6 +28,8 @@
 ;;   <[email-masked]>.
 ;;
 ;; - QWERTY-based Georgian.
+;;
+;; - QWERTY-based Nuskhuri script.
 
 ;;; Code:
 
@@ -131,4 +133,50 @@
  ("G" ?ჷ)
  )
 
+(quail-define-package
+ "georgian-nuskhuri" "Georgian" "ⴌ" t
+ "Nuskhuri Georgian (QWERTY-based)."
+ nil t nil nil t nil nil nil nil nil t)
+
+(quail-define-rules
+ ("a" ?ⴀ)
+ ("b" ?ⴁ)
+ ("g" ?ⴂ)
+ ("d" ?ⴃ)
+ ("e" ?ⴄ)
+ ("v" ?ⴅ)
+ ("z" ?ⴆ)
+ ("T" ?ⴇ)
+ ("i" ?ⴈ)
+ ("k" ?ⴉ)
+ ("l" ?ⴊ)
+ ("m" ?ⴋ)
+ ("n" ?ⴌ)
+ ("o" ?ⴍ)
+ ("p" ?ⴎ)
+ ("J" ?ⴏ)
+ ("r" ?ⴐ)
+ ("s" ?ⴑ)
+ ("t" ?ⴒ)
+ ("u" ?ⴓ)
+ ("f" ?ⴔ)
+ ("q" ?ⴕ)
+ ("R" ?ⴖ)
+ ("y" ?ⴗ)
+ ("S" ?ⴘ)
+ ("C" ?ⴙ)
+ ("c" ?ⴚ)
+ ("Z" ?ⴛ)
+ ("w" ?ⴜ)
+ ("W" ?ⴝ)
+ ("x" ?ⴞ)
+ ("j" ?ⴟ)
+ ("h" ?ⴠ)
+ ("X" ?ⴤ)
+ ("H" ?ⴡ)
+ ("K" ?ⴥ)
+ ("I" ?ⴢ)
+ ("V" ?ⴣ)
+ )
+
 ;;; georgian.el ends here
-- 
2.17.1

From 39c1b3f1d094ee6d0a6487040c29ec83a62658df Mon Sep 17 00:00:00 2001
From: Nick Drozd <[email-masked]>
Date: Sat, 13 Jul 2019 12:04:12 -0500
Subject: [PATCH 4/5] * etc/HELLO: Fix name of Georgian language

---
 etc/HELLO | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/etc/HELLO b/etc/HELLO
index 25306258cf..39c39651b4 100644
--- a/etc/HELLO
+++ b/etc/HELLO
@@ -47,7 +47,7 @@ Emoji	👋
 </x-charset><x-charset><param>latin-iso8859-15</param>Estonian (eesti keel)	Tere päevast / Tere õhtust
 </x-charset><x-charset><param>latin-iso8859-1</param>Finnish (suomi)	Hei / Hyvää päivää
 French (français)	Bonjour / Salut
-</x-charset><x-charset><param>mule-unicode-0100-24ff</param>Georgian (ქართველი)	გამარჯობა
+</x-charset><x-charset><param>mule-unicode-0100-24ff</param>Georgian (ქართული)	გამარჯობა
 </x-charset><x-charset><param>latin-iso8859-1</param>German (Deutsch)	Guten Tag / Grüß Gott
 </x-charset><x-charset><param>greek-iso8859-7</param>Greek (ελληνικά)	Γειά σας
 </x-charset><x-charset><param>mule-unicode-0100-24ff</param>Greek, ancient (ἑλληνική)	Οὖλέ τε καὶ μέγα χαῖρε
-- 
2.17.1

From 8aedc7abb9bd9e0150d09a43c911ac4dbcc9f854 Mon Sep 17 00:00:00 2001
From: Nick Drozd <[email-masked]>
Date: Sat, 13 Jul 2019 12:04:21 -0500
Subject: [PATCH 5/5] * etc/NEWS: Announce new Georgian inputs

---
 etc/NEWS | 3 +++
 1 file changed, 3 insertions(+)

diff --git a/etc/NEWS b/etc/NEWS
index 4680021401..826ce83a24 100644
--- a/etc/NEWS
+++ b/etc/NEWS
@@ -303,6 +303,9 @@ regular expression was previously invalid, but is now accepted:
 ---
 ** New input methods 'hawaiian-postfix' and 'hawaiian-prefix'.
 
+---
+** New input methods 'georgian-qwerty' and 'georgian-nuskhuri'.
+
 ---
 ** New input methods for several variants of the Sami language.
 The Sami input methods include: 'norwegian-sami-prefix',
diff --git a/lisp/leim/quail/georgian.el b/lisp/leim/quail/georgian.el
index 61003b8f99..7ca3f79a81 100644
--- a/lisp/leim/quail/georgian.el
+++ b/lisp/leim/quail/georgian.el
@@ -22,8 +22,12 @@
 
 ;;; Commentary:
 
 ;; Georgian input following the Yudit map from Mark Leisher
 ;; <[email-masked]>.
 
 ;;; Code:
 
@@ -80,4 +84,53 @@
  ("e1" ?) ;; Letter not in Unicode (private use code).
  )
 
+(quail-define-package
+ "georgian-qwerty" "Georgian" "ქ" t
+ "Georgian input based on QWERTY keyboard."
+ nil t nil nil t nil nil nil nil nil t)
+
+(quail-define-rules
+ ("a" ?ა)
+ ("b" ?ბ)
+ ("g" ?გ)
+ ("d" ?დ)
+ ("e" ?ე)
+ ("v" ?ვ)
+ ("z" ?ზ)
+ ("T" ?თ)
+ ("i" ?ი)
+ ("k" ?კ)
+ ("l" ?ლ)
+ ("m" ?მ)
+ ("n" ?ნ)
+ ("o" ?ო)
+ ("p" ?პ)
+ ("J" ?ჟ)
+ ("r" ?რ)
+ ("s" ?ს)
+ ("t" ?ტ)
+ ("u" ?უ)
+ ("f" ?ფ)
+ ("q" ?ქ)
+ ("R" ?ღ)
+ ("y" ?ყ)
+ ("S" ?შ)
+ ("C" ?ჩ)
+ ("c" ?ც)
+ ("Z" ?ძ)
+ ("w" ?წ)
+ ("W" ?ჭ)
+ ("x" ?ხ)
+ ("j" ?ჯ)
+ ("h" ?ჰ)
+ ("X" ?ჴ)
+ ("H" ?ჱ)
+ ("K" ?ჵ)
+ ("I" ?ჲ)
+ ("V" ?ჳ)
+ ("F" ?ჶ)
+ ("Y" ?ჸ)
+ ("G" ?ჷ)
+ )
+
 ;;; georgian.el ends here
@@ -22,8 +22,12 @@
 ;;; Commentary:
 
-;; Georgian input following the Yudit map from Mark Leisher
-;; <[email-masked]>.
+;; This file defines the following Georgian keyboards:
+;;
+;; - Georgian input following the Yudit map from Mark Leisher
+;;   <[email-masked]>.
+;;
+;; - QWERTY-based Georgian.
 
 ;;; Code:
-- 
2.17.1